# Craft Archives

[![Documentation Status][rtd-badge]][rtd-latest]
[![Codecov Status][codecov-badge]][codecov-status]
[![Ruff status][ruff-badge]][ruff-site]

Craft Archives is a Python package to manage interaction with software package
repositories on behalf of tools using the [Craft Parts] library.

Craft Archives provides a set of common interfaces to define the locations of
and install new repositories.

It aims to provide a uniform, extensible set of interfaces that other tools and
packages can use when working with repositories.

This package is most useful for developers who write tools with [Craft Parts]
and need to provide support for additional software package repositories.

## Documentation

The [Craft Archives documentation][rtd-latest] provides guidance about
understanding and using the library.

## Community and support

You can report any issues or bugs on the project's [GitHub
repository](https://github.com/canonical/craft-archives/issues).

Craft Archives is covered by the [Ubuntu Code of
Conduct](https://ubuntu.com/community/ethos/code-of-conduct).

## Contribute to Craft Archives

Craft Archives is open source and part of the Canonical family. We would love your help.

If you're interested, start with the [contribution guide](HACKING.md).

We welcome any suggestions and help with the docs. The [Canonical Open Documentation
Academy](https://github.com/canonical/open-documentation-academy) is the hub for doc
development, including Craft Archives docs. No prior coding experience is required.

## License and copyright

Craft Archives is released under the [GPL-3.0 license](LICENSE).

© 2023-2025 Canonical Ltd.

[rtd-badge]: https://readthedocs.com/projects/canonical-craft-archives/badge/?version=latest
[rtd-latest]: https://canonical-craft-archives.readthedocs-hosted.com/en/latest/
[ruff-badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json
[ruff-site]: https://github.com/astral-sh/ruff
[codecov-badge]: https://codecov.io/github/canonical/craft-archives/coverage.svg?branch=main
[codecov-status]: https://codecov.io/github/canonical/craft-archives?branch=main
[Craft Parts]: https://canonical-craft-parts.readthedocs-hosted.com/en/latest/
